@@ -2,13 +2,17 @@ use strict; use warnings;
 package
 assign::Test;
 
+use assign::0();
 use Test::More;
 use Capture::Tiny;
 use XXX;
 
 use base 'Exporter';
 
+our $t = -d 't' ? 't' : 'test';
+
 our @EXPORT = qw(
+    $t
     test
     is ok pass fail like
     capture
@@ -28,7 +32,7 @@ sub test {
         defined $ENV{TEST_ONLY} and
         $ENV{TEST_ONLY} != ++$test_count;
 
-    require assign;
+    $assign::assign_class = 'assign::0';
     $assign::var_prefix = '_';
     $assign::var_id = 0;
 
